@@ -17,7 +17,6 @@
 #' @importFrom broom tidy glance
 #' @importFrom dplyr select filter bind_cols
 #' @importFrom stats glm
-#' @importFrom margins margins
 konfound_glm <- function(model_object, 
                          tested_variable_string, 
                          alpha, tails, 
@@ -28,9 +27,10 @@ konfound_glm <- function(model_object,
     
     coef_df <- tidy_output[tidy_output$term == tested_variable_string, ]
     est_eff <- coef_df$estimate
-    est_eff <- suppressWarnings(
-      summary(margins::margins(model_object))$AME[names(summary(
-        margins::margins(model_object))$AME) == tested_variable_string])
+    warning("Due to an issue with the margins and predictions package, these are the raw coefficients, not the average marginal effects; we will address this in future patches")
+    # est_eff <- suppressWarnings(
+    #   summary(margins::margins(model_object))$AME[names(summary(
+    #     margins::margins(model_object))$AME) == tested_variable_string])
     std_err <- coef_df$std.error
     n_obs <- glance_output$nobs
     n_covariates <- glance_output$df.null - glance_output$df.residual
